@@ -15,8 +15,8 @@
 #
 # Copyright (C) 2012 Dominik Kriegner <dominik.kriegner@gmail.com>
 
-import xrayutilities as xu
 import numpy
+import xrayutilities as xu
 
 # config for kappa geometry
 # set it either in the script or include it in on of the config files
@@ -28,7 +28,7 @@ xu.config.KAPPA_ANGLE = -60
 # http://en.wikipedia.org/wiki/File:Kappa_goniometer_animation.ogg
 qconv = xu.experiment.QConversion(['z+', 'k+', 'z+'], ['z+'], (1, 0, 0))
 
-print qconv
+print(qconv)
 
 print("angles: 0, 0, 0, 90")
 (qx, qy, qz) = qconv(0, 0, 0, 90)
