@@ -15,9 +15,10 @@
 #
 # Copyright (C) 2013 Dominik Kriegner <dominik.kriegner@gmail.com>
 
+import os
+
 import matplotlib.pyplot as plt
 import xrayutilities as xu
-import os
 
 # global setting for the experiment
 sample = "testnja"  # sample name used also as file name for the data file
@@ -40,7 +41,7 @@ INT = xu.maplog(gridder.data.transpose(), 6, 0)
 plt.figure()
 plt.clf()
 cf = plt.contourf(gridder.xaxis, gridder.yaxis, INT, 100, extend='min')
-plt.xlabel(r'$Q_{[110]}$ ($\AA^{-1}$)')
-plt.ylabel(r'$Q_{[001]}$ ($\AA^{-1}$)')
+plt.xlabel(r'$Q_{[110]}$ ($\mathrm{\AA}^{-1}$)')
+plt.ylabel(r'$Q_{[001]}$ ($\mathrm{\AA}^{-1}$)')
 cb = plt.colorbar(cf)
 cb.set_label(r"$\log($Int$)$ (cps)")
