@@ -14,7 +14,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # Copyright (C) 2009 Eugen Wintersberger <eugen.wintersberger@desy.de>
-# Copyright (C) 2009-2019 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2009-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
 # Copyright (C) 2012 Tanja Etzelstorfer <tanja.etzelstorfer@jku.at>
 
 """
@@ -29,11 +29,10 @@ import numbers
 import operator
 import re
 import warnings
-from math import ceil, copysign
+from math import ceil, copysign, isclose
 
 import numpy
 import scipy.optimize
-from pkg_resources import parse_version
 
 from .. import config, math, utilities
 from ..exception import InputError
@@ -89,10 +88,10 @@ def Cij2Cijkl(cij):
     for i in range(0, 3):
         for j in range(0, 3):
             for k in range(0, 3):
-                for l in range(0, 3):
+                for n in range(0, 3):
                     mi = index_map_ijkl2ij(i, j)
-                    mj = index_map_ijkl2ij(k, l)
-                    cijkl[i, j, k, l] = m[mi, mj]
+                    mj = index_map_ijkl2ij(k, n)
+                    cijkl[i, j, k, n] = m[mi, mj]
     return cijkl
 
 
@@ -275,7 +274,7 @@ class Material(utilities.ABC):
             d = numpy.get_printoptions()
             numpy.set_printoptions(precision=2, linewidth=78, suppress=False)
             ostr += str(self.cij) + '\n'
-            numpy.set_printoptions(d)
+            numpy.set_printoptions(**d)
 
         return ostr
 
@@ -303,7 +302,7 @@ class Amorphous(Material):
             name is a simply chemical formula then this can be None.  To
             specify more complicated materials use [('Ir', 0.2), ('Mn', 0.8),
             ...].  Instead of the elements as string you can also use an Atom
-            object.  If the contents to not add up to 1 they will be corrected
+            object.  If the contents to not add up to 1 they will be normalized
             without notice.
         cij :       array-like, optional
             elasticity matrix
@@ -502,7 +501,7 @@ class Crystal(Material):
             self.thetaDebye = thetaDebye
 
     @classmethod
-    def fromCIF(cls, ciffilestr):
+    def fromCIF(cls, ciffilestr, **kwargs):
         """
         Create a Crystal from a CIF file. The default data-set from the cif
         file will be used to create the Crystal.
@@ -511,12 +510,14 @@ class Crystal(Material):
         ----------
         ciffilestr :    str, bytes
             filename of the CIF file or string representation of the CIF file
+        kwargs : dict
+            keyword arguments are passed to the init-method of CIFFile
 
         Returns
         -------
         Crystal
         """
-        cf = cif.CIFFile(ciffilestr)
+        cf = cif.CIFFile(ciffilestr, **kwargs)
         lat = cf.SGLattice()
         return cls(cf.data[cf._default_dataset].name, lat)
 
@@ -582,7 +583,7 @@ class Crystal(Material):
 
     @property
     def B(self):
-        return self.lattice.qtransform.matrix
+        return self.lattice._qtransform.matrix
 
     def __eq__(self, other):
         """
@@ -679,8 +680,9 @@ class Crystal(Material):
 
     def environment(self, *pos, **kwargs):
         """
-        Returns a list of neighboring atoms for a given position within the the
-        unit cell.
+        Returns a list of neighboring atoms for a given position within the
+        unit cell. If the material does not contain any atoms a dummy atom will
+        be placed on the unit cell corners.
 
         Parameters
         ----------
@@ -706,49 +708,51 @@ class Crystal(Material):
                 raise InputError("need 3 coordinates of the "
                                  "reference position")
 
-        refpos = self.a1 * \
-            pos[0] + self.a2 * pos[1] + self.a3 * pos[2]
-
+        refpos = self.lattice._ai.T @ pos
         lst = []
-        Na = 2 * int(ceil(maxdist / math.VecNorm(self.a1)))
-        Nb = 2 * int(ceil(maxdist / math.VecNorm(self.a2)))
-        Nc = 2 * int(ceil(maxdist / math.VecNorm(self.a3)))
-        if self.lattice.nsites > 0:
-            for a, p, o, b in self.lattice.base():
-                ucpos = (self.a1 * p[0] + self.a2 * p[1] + self.a3 * p[2])
-                for i in range(-Na, Na + 1):
-                    for j in range(-Nb, Nb + 1):
-                        for k in range(-Nc, Nc + 1):
-                            atpos = ucpos + (self.a1 * i + self.a2 * j +
-                                             self.a3 * k)
-                            distance = math.VecNorm(atpos - refpos)
-                            if distance <= maxdist:
-                                lst.append((distance, a, o))
-        else:
-            for i in range(-Na, Na + 1):
-                for j in range(-Nb, Nb + 1):
-                    for k in range(-Nc, Nc + 1):
-                        atpos = (self.a1 * i + self.a2 * j + self.a3 * k)
-                        distance = math.VecNorm(atpos - refpos)
-                        if distance <= maxdist:
-                            lst.append((distance, '__dummy__', 1.))
 
-        # sort
-        lst.sort(key=operator.itemgetter(1))
-        lst.sort(key=operator.itemgetter(0))
-        rl = []
-        if len(lst) >= 1:
-            mult = lst[0][2]
+        # determine lattice base
+        if self.lattice.nsites > 0:
+            base = list(self.lattice.base())
         else:
+            base = [(elements.Dummy, (0, 0, 0), 1, 0)]
+
+        # find maximally needed super cell
+        na = int(ceil(maxdist / math.VecNorm(self.a1)))
+        nb = int(ceil(maxdist / math.VecNorm(self.a2)))
+        nc = int(ceil(maxdist / math.VecNorm(self.a3)))
+        nab = int(ceil(maxdist / math.VecNorm(self.a1 + self.a2)))
+        nac = int(ceil(maxdist / math.VecNorm(self.a1 + self.a3)))
+        nbc = int(ceil(maxdist / math.VecNorm(self.a2 + self.a3)))
+        nabc = int(ceil(maxdist / math.VecNorm(self.a1 + self.a2 + self.a3)))
+        Na = max(na, nab, nac, nabc)
+        Nb = max(nb, nab, nbc, nabc)
+        Nc = max(nc, nac, nbc, nabc)
+
+        # determine distance of all atoms w.r.t. the refpos
+        ucidx = numpy.mgrid[-Na:Na+1, -Nb:Nb+1, -Nc:Nc+1].reshape(3, -1)
+        for a, p, o, b in base:
+            ucpos = self.lattice._ai.T @ p
+            pos = ucpos + numpy.einsum('ji, ...i', self.lattice._ai.T, ucidx.T)
+            distance = math.VecNorm(pos - refpos)
+            lst += [(d, a, o) for d in distance]
+
+        # sort and merge return list
+        lst.sort(key=operator.itemgetter(0, 1))
+        rl = []
+        if len(lst) < 1 or lst[0][0] > maxdist:
             return rl
+
+        mult = lst[0][2]
         for i in range(1, len(lst)):
-            if (abs(lst[i - 1][0] - lst[i][0]) < config.EPSILON and
+            if (isclose(lst[i - 1][0] - lst[i][0], 0, abs_tol=1e-8) and
                     lst[i - 1][1] == lst[i][1]):
                 mult += lst[i - 1][2]  # add occupancy
             else:
                 rl.append((lst[i - 1][0], lst[i - 1][1], mult))
                 mult = lst[i][2]
-        rl.append((lst[-1][0], lst[-1][1], mult))
+            if lst[i][0] > maxdist:
+                break
 
         return rl
 
@@ -1274,8 +1278,7 @@ class Crystal(Material):
         self._distances = [0]
         self._dis_hist = [0]
         for dis in tmp_data:
-            if numpy.round(dis - self._distances[-1],
-                           int(abs(numpy.log10(config.EPSILON)))) == 0:
+            if numpy.round(dis - self._distances[-1], config.DIGITS) == 0:
                 self._dis_hist[-1] += 1
             else:
                 self._distances.append(dis)
@@ -1289,46 +1292,107 @@ class Crystal(Material):
         return ret
 
     def show_unitcell(self, fig=None, subplot=111, scale=0.6, complexity=11,
-                      linewidth=2):
+                      linewidth=1.5, mode='matplotlib'):
         """
-        primitive visualization of the unit cell using matplotlibs basic 3D
-        functionality -> expect rendering inaccuracies!
+        visualization of the unit cell using either matplotlibs basic 3D
+        functionality (expect rendering inaccuracies!) or the mayavi mlab
+        package (accurate rendering -> recommended!)
 
         Note:
-            For more precise visualization export to CIF and use a proper
-            crystal structure viewer.
+            For more flexible visualization consider using the CIF-export
+            feature and use a proper crystal structure viewer.
 
         Parameters
         ----------
-        fig :   matplotlib Figure or None, optional
+        fig :   matplotlib Figure, Mayavi Scene, or None, optional
         subplot :   int or list, optional
-            subplot to use for the visualization. This argument of fowarded to
-            the first argument of matplotlibs `add_subplot` function
+            subplot to use for the visualization when using matplotlib. This
+            argument of fowarded to the first argument of matplotlibs
+            `add_subplot` function
         scale :     float, optional
             scale the size of the atoms by this additional factor. By default
             the size of the atoms corresponds to 60% of their atomic radius.
         complexity :    int, optional
-            number of steps to approximate the atoms as spheres. higher values
-            cause significant slower plotting.
+            number of steps to approximate the atoms as spheres. Higher values
+            make spheres more accurate, but cause slower plotting.
         linewidth :     float, optional
             line thickness of the unit cell outline
+        mode :      str, optional
+            defines the plot backend used, can be 'matplotlib' (default)
+            or 'mayavi'.
+
+        Returns
+        -------
+        figure object of either matplotlib or Mayavi
         """
-        plot, plt = utilities.import_matplotlib_pyplot('XU.materials')
-        try:
-            import mpl_toolkits.mplot3d
-        except ImportError:
-            plot = False
+        if mode == 'matplotlib':
+            plot, plt = utilities.import_matplotlib_pyplot('XU.materials')
+            try:
+                import mpl_toolkits.mplot3d
+            except ImportError:
+                plot = False
+        else:
+            plot, mlab = utilities.import_mayavi_mlab('XU.materials')
+            try:
+                import mayavi
+                from matplotlib.colors import to_rgb
+            except ImportError:
+                plot = False
 
         if not plot:
-            print('matplotlib (including mplot3d) needed for show_unitcell()')
+            print('matplotlib and/or mayavi.mlab needed for show_unitcell()')
             return
 
-        if fig is None:
-            fig = plt.figure()
-        ax = fig.add_subplot(subplot, projection='3d')
+        def plot_sphere(fig, vecpos, r, alpha, complexity, color):
+            """
+            Visualize a sphere using either matplotlib or Mayavi
+            """
+            if mode == 'matplotlib':
+                ax = fig.gca()
+                phi, theta = numpy.mgrid[0:numpy.pi:1j*complexity,
+                                         0:2*numpy.pi:1j*complexity]
 
-        phi, theta = numpy.mgrid[0:numpy.pi:1j*complexity,
-                                 0:2*numpy.pi:1j*complexity]
+                x = r*numpy.sin(phi)*numpy.cos(theta) + vecpos[0]
+                y = r*numpy.sin(phi)*numpy.sin(theta) + vecpos[1]
+                z = r*numpy.cos(phi) + vecpos[2]
+                ax.plot_surface(x, y, z,  rstride=1, cstride=1,
+                                color=color, alpha=alpha,
+                                linewidth=0)
+            else:
+                mlab.points3d(vecpos[0], vecpos[1], vecpos[2], r,
+                              opacity=alpha, transparent=False,
+                              color=to_rgb(color), resolution=complexity,
+                              scale_factor=2, figure=fig)
+
+        def plot_line(fig, start, end, color, linewidth):
+            """
+            Draw a line between two 3D points, either using matplotlib or
+            Mayavi.
+            """
+            if mode == 'matplotlib':
+                ax = fig.gca()
+                ax.plot((start[0], end[0]),
+                        (start[1], end[1]),
+                        (start[2], end[2]),
+                        color=color, lw=linewidth)
+            else:
+                mlab.plot3d((start[0], end[0]),
+                            (start[1], end[1]),
+                            (start[2], end[2]),
+                            color=to_rgb(color), tube_radius=linewidth/20,
+                            figure=fig)
+
+        if mode == 'matplotlib':
+            if fig is None:
+                fig = plt.figure()
+            elif not isinstance(fig, plt.Figure):
+                raise TypeError("'fig' argument must be a matplotlib figure!")
+            ax = fig.add_subplot(subplot, projection='3d')
+        else:
+            if fig is None:
+                fig = mlab.figure(bgcolor=(1, 1, 1))
+            elif not isinstance(fig, mayavi.core.scene.Scene):
+                raise TypeError("'fig' argument must be a Mayavi Scene!")
 
         for a, pos, occ, b in self.lattice.base():
             r = a.radius * scale
@@ -1336,67 +1400,40 @@ class Crystal(Material):
                 for j in range(-1, 2):
                     for k in range(-1, 2):
                         atpos = (pos + [i, j, k])
-                        inunitcell = True
-                        for l in range(3):
-                            if (atpos[l] < -config.EPSILON or
-                                    atpos[l] > 1+config.EPSILON):
-                                inunitcell = False
-                        if inunitcell:
+                        if all(a > -config.EPSILON and a < 1+config.EPSILON
+                               for a in atpos):
                             vecpos = atpos[0]*self.a1 + atpos[1]*self.a2 +\
                                      atpos[2]*self.a3
-                            x = r*numpy.sin(phi)*numpy.cos(theta) + vecpos[0]
-                            y = r*numpy.sin(phi)*numpy.sin(theta) + vecpos[1]
-                            z = r*numpy.cos(phi) + vecpos[2]
-                            ax.plot_surface(x, y, z,  rstride=1, cstride=1,
-                                            color=a.color, alpha=occ,
-                                            linewidth=0)
+                            plot_sphere(fig, vecpos, r, occ, complexity,
+                                        a.color)
 
         # plot unit cell outlines
-        ax.plot([0, self.a1[0]], [0, self.a1[1]], [0, self.a1[2]], color='k',
-                lw=linewidth)
-        ax.plot([0, self.a2[0]], [0, self.a2[1]], [0, self.a2[2]], color='k',
-                lw=linewidth)
-        ax.plot([0, self.a3[0]], [0, self.a3[1]], [0, self.a3[2]], color='k',
-                lw=linewidth)
-        ax.plot([self.a1[0], self.a1[0]+self.a2[0]],
-                [self.a1[1], self.a1[1]+self.a2[1]],
-                [self.a1[2], self.a1[2]+self.a2[2]], color='k', lw=linewidth)
-        ax.plot([self.a1[0], self.a1[0]+self.a3[0]],
-                [self.a1[1], self.a1[1]+self.a3[1]],
-                [self.a1[2], self.a1[2]+self.a3[2]], color='k', lw=linewidth)
-        ax.plot([self.a2[0], self.a1[0]+self.a2[0]],
-                [self.a2[1], self.a1[1]+self.a2[1]],
-                [self.a2[2], self.a1[2]+self.a2[2]], color='k', lw=linewidth)
-        ax.plot([self.a2[0], self.a2[0]+self.a3[0]],
-                [self.a2[1], self.a2[1]+self.a3[1]],
-                [self.a2[2], self.a2[2]+self.a3[2]], color='k', lw=linewidth)
-        ax.plot([self.a3[0], self.a1[0]+self.a3[0]],
-                [self.a3[1], self.a1[1]+self.a3[1]],
-                [self.a3[2], self.a1[2]+self.a3[2]], color='k', lw=linewidth)
-        ax.plot([self.a3[0], self.a2[0]+self.a3[0]],
-                [self.a3[1], self.a2[1]+self.a3[1]],
-                [self.a3[2], self.a2[2]+self.a3[2]], color='k', lw=linewidth)
-        ax.plot([self.a1[0]+self.a2[0], self.a1[0]+self.a2[0]+self.a3[0]],
-                [self.a1[1]+self.a2[1], self.a1[1]+self.a2[1]+self.a3[1]],
-                [self.a1[2]+self.a2[2], self.a1[2]+self.a2[2]+self.a3[2]],
-                color='k', lw=linewidth)
-        ax.plot([self.a1[0]+self.a3[0], self.a1[0]+self.a2[0]+self.a3[0]],
-                [self.a1[1]+self.a3[1], self.a1[1]+self.a2[1]+self.a3[1]],
-                [self.a1[2]+self.a3[2], self.a1[2]+self.a2[2]+self.a3[2]],
-                color='k', lw=linewidth)
-        ax.plot([self.a2[0]+self.a3[0], self.a1[0]+self.a2[0]+self.a3[0]],
-                [self.a2[1]+self.a3[1], self.a1[1]+self.a2[1]+self.a3[1]],
-                [self.a2[2]+self.a3[2], self.a1[2]+self.a2[2]+self.a3[2]],
-                color='k', lw=linewidth)
+        plot_line(fig, (0, 0, 0), self.a1, 'k', linewidth)
+        plot_line(fig, (0, 0, 0), self.a2, 'k', linewidth)
+        plot_line(fig, (0, 0, 0), self.a3, 'k', linewidth)
+        plot_line(fig, self.a1, self.a1+self.a2, 'k', linewidth)
+        plot_line(fig, self.a1, self.a1+self.a3, 'k', linewidth)
+        plot_line(fig, self.a2, self.a1+self.a2, 'k', linewidth)
+        plot_line(fig, self.a2, self.a2+self.a3, 'k', linewidth)
+        plot_line(fig, self.a3, self.a1+self.a3, 'k', linewidth)
+        plot_line(fig, self.a3, self.a2+self.a3, 'k', linewidth)
+        plot_line(fig, self.a1+self.a2, self.a1+self.a2+self.a3, 'k',
+                  linewidth)
+        plot_line(fig, self.a1+self.a3, self.a1+self.a2+self.a3, 'k',
+                  linewidth)
+        plot_line(fig, self.a2+self.a3, self.a1+self.a2+self.a3, 'k',
+                  linewidth)
 
-        if parse_version(plt.matplotlib.__version__) < parse_version('3.1.0'):
-            ax.set_aspect("equal")
+        if mode == 'matplotib':
+            if config.VERBOSITY >= config.INFO_LOW:
+                warnings.warn("show_unitcell: 3D projection might appear "
+                              "distorted (limited 3D capabilities of "
+                              "matplotlib!). Use mayavi mode or CIF "
+                              "export and other viewers for better "
+                              "visualization.")
+            plt.tight_layout()
 
-        if config.VERBOSITY >= config.INFO_LOW:
-            warnings.warn("show_unitcell: 3D projection might appear distorted"
-                          "(limited 3D capabilities of matplotlib!). Use CIF "
-                          "export and other viewers for better visualization.")
-        plt.tight_layout()
+        return fig
 
 
 def CubicElasticTensor(c11, c12, c44):
@@ -1654,7 +1691,7 @@ class Alloy(Crystal):
         # test if inplane direction of hkl is the same as the one for the
         # experiment otherwise warn the user
         hklinplane = VecCross(VecCross(exp.ndir, hkl), exp.ndir)
-        if (VecNorm(VecCross(hklinplane, exp.idir)) > config.EPSILON):
+        if not numpy.isclose(VecNorm(VecCross(hklinplane, exp.idir)), 0):
             warnings.warn("Alloy: given hkl differs from the geometry of the "
                           "Experiment instance in the azimuthal direction")
 
