@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2012-2018 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2012-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
 """
 module with a function wrapper to scipy.optimize.leastsq
 for fitting of a 2D function to a peak or a 1D Gauss fit with
@@ -21,6 +21,7 @@ the odr package
 """
 
 import time
+import warnings
 
 import numpy
 import scipy.optimize as optimize
@@ -167,11 +168,11 @@ def peak_fit(xdata, ydata, iparams=[], peaktype='Gauss', maxit=300,
             plt.figure(plot)
         else:
             plt.figure('XU:peak_fit')
-        plt.plot(xdata, ydata, 'ko', label='data', mew=2)
+        plt.plot(xdata, ydata, 'ok', label='data', mew=2)
         if debug:
             plt.plot(xdata, gfunc(iparams, xdata), '-', color='0.5',
                      label='estimate')
-        plt.plot(xdata, gfunc(fparam, xdata), 'r-',
+        plt.plot(xdata, gfunc(fparam, xdata), '-r',
                  label='%s-fit' % peaktype)
         plt.legend()
 
@@ -439,17 +440,8 @@ def fit_peak2d(x, y, data, start, drange, fit_function, maxfev=2000):
     return p, pcov
 
 
-def multGaussFit(*args, **kwargs):
-    """
-    convenience function to keep API stable
-    see multPeakFit for documentation
-    """
-    kwargs['peaktype'] = 'Gaussian'
-    return multPeakFit(*args, **kwargs)
-
-
 def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
-                peaktype='Gaussian'):
+                peaktype='Gaussian', returnerror=False):
     """
     function to fit multiple Gaussian/Lorentzian peaks with linear background
     to a set of data
@@ -469,6 +461,9 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
         not need to have the same number of entries as peakpos
     peaktype : {'Gaussian', 'Lorentzian'}
         type of peaks to be used
+    returnerror : bool
+        decides if the fit errors of pos, sigma, and amp are returned (default:
+        False)
 
     Returns
     -------
@@ -480,7 +475,16 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
         amplitudes of the peaks derived by the fit
     background :    array-like
         background values at positions `x`
+    if returnerror == True:
+     sd_pos :   list
+        standard error of peak positions as returned by scipy.odr.Output
+     sd_sigma : list
+        standard error of the peak width
+     sd_amp :   list
+        standard error of the peak amplitude
     """
+    warnings.warn("deprecated function -> use the lmfit Python packge instead",
+                  DeprecationWarning)
     if peaktype == 'Gaussian':
         pfunc = Gauss1d
         pfunc_derx = Gauss1d_der_x
@@ -605,7 +609,17 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
     p = []
 
     # background
-    k, d = numpy.polyfit(lx, ldata, 1)
+    # exclude +/-2 peakwidth around the peaks
+    bmask = numpy.ones_like(lx, dtype=bool)
+    for pp, pw in zip(peakpos, peakwidth):
+        bmask = numpy.logical_and(bmask, numpy.logical_or(lx < (pp-2*pw),
+                                                          lx > (pp+2*pw)))
+    if numpy.any(bmask):
+        k, d = numpy.polyfit(lx[bmask], ldata[bmask], 1)
+    else:
+        if(config.VERBOSITY >= config.DEBUG):
+            print("XU.math.multPeakFit: no data outside peak regions!")
+        k, d = (0, ldata.min())
 
     # peak parameters
     for i in range(len(peakpos)):
@@ -617,7 +631,7 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
     p += [k, d]
 
     if(config.VERBOSITY >= config.DEBUG):
-        print("XU.math.multGaussFit: intial parameters")
+        print("XU.math.multPeakFit: intial parameters")
         print(p)
 
     ##########################
@@ -636,7 +650,7 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
         if fit.stopreason[0] not in ['Sum of squares convergence']:
             print("XU.math.multPeakFit: fit NOT converged (%s)"
                   % fit.stopreason[0])
-            return None, None, None, None
+            return Nono, None, None, None
     except IndexError:
         print("XU.math.multPeakFit: fit most probably NOT converged (%s)"
               % str(fit.stopreason))
@@ -646,19 +660,14 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
     fwidth = numpy.abs(fit.beta[1:-2:3])
     famp = fit.beta[2::3]
     background = numpy.polyval((fit.beta[-2], fit.beta[-1]), x)
-
+    if returnerror:
+        sd_pos = fit.sd_beta[:-2:3]
+        sd_width = fit.sd_beta[1:-2:3]
+        sd_amp = fit.sd_beta[2::3]
+        return fpos, fwidth, famp, background, sd_pos, sd_width, sd_amp
     return fpos, fwidth, famp, background
 
 
-def multGaussPlot(*args, **kwargs):
-    """
-    convenience function to keep API stable
-    see multPeakPlot for documentation
-    """
-    kwargs['peaktype'] = 'Gaussian'
-    return multPeakPlot(*args, **kwargs)
-
-
 def multPeakPlot(x, fpos, fwidth, famp, background, dranges=None,
                  peaktype='Gaussian', fig="xu_plot", ax=None, fact=1.):
     """
@@ -689,6 +698,8 @@ def multPeakPlot(x, fpos, fwidth, famp, background, dranges=None,
     fact :      float
         factor to use as multiplicator in the plot
     """
+    warnings.warn("deprecated function -> use the lmfit Python packge instead",
+                  DeprecationWarning)
     success, plt = utilities.import_matplotlib_pyplot('XU.math.multPeakPlot')
     if not success:
         return
@@ -719,7 +730,7 @@ def multPeakPlot(x, fpos, fwidth, famp, background, dranges=None,
         else:
             raise ValueError('wrong value for parameter peaktype was given')
         f += lf
-        plt.plot(lx, (lf + lb) * fact, 'k:')
+        plt.plot(lx, (lf + lb) * fact, ':k')
 
     # plot summed signal
-    plt.plot(lx, (f + lb) * fact, 'r-', lw=1.5)
+    plt.plot(lx, (f + lb) * fact, '-r', lw=1.5)
