@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2016-2019 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2016-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import warnings
 
@@ -24,203 +24,6 @@ from ..exception import InputError
 from . import models
 
 
-def fit_xrr(reflmod, params, ai, data=None, eps=None, xmin=-numpy.inf,
-            xmax=numpy.inf, plot=False, verbose=False, elog=True, maxfev=500):
-    """
-    optimize function for a Reflectivity Model using lmfit. The fitting
-    parameters must be specified as instance of lmfits Parameters class.
-
-    Parameters
-    ----------
-    reflmod :   SpecularReflectivityModel
-        preconfigured model used for the fitting
-    params :    lmfit.Parameters
-        instance of lmfits Parameters class. For every layer the parameters
-        '{}_thickness', '{}_roughness', '{}_density', with '{}' representing
-        the layer name are supported. In addition the setup parameters:
-
-          - 'I0' primary beam intensity
-          - 'background' background added to the simulation
-          - 'sample_width' size of the sample along the beam
-          - 'beam_width' width of the beam in the same units
-          - 'resolution_width' width of the resolution function in deg
-          - 'shift' experimental shift of the incidence angle array
-
-    ai :        array-like
-        array of incidence angles for the calculation
-    data :      array-like
-        experimental data which should be fitted
-    eps :       array-like, optional
-        error bar of the data
-    xmin :      float, optional
-        minimum value of ai which should be used. a mask is generated to cut
-        away other data
-    xmax :      float, optional
-        maximum value of ai which should be used. a mask is generated to cut
-        away other data
-    plot :      bool, optional
-        flag to decide wheter an plot should be created showing the fit's
-        progress. If plot is a string it will be used as figure name, which
-        makes reusing the figures easier.
-    verbose :   bool, optional
-        flag to tell if the variation of the fitting error should be output
-        during the fit.
-    elog :      bool, optional
-        logarithmic error during the fit
-    maxfev :    int, optional
-        maximum number of function evaluations during the leastsq optimization
-
-    Returns
-    -------
-    res : lmfit.MinimizerResult
-        object from lmfit, which contains the fitted parameters in res.params
-        (see res.params.pretty_print) or try lmfit.report_fit(res)
-    """
-    warnings.warn("deprecated function -> change to FitModel",
-                  DeprecationWarning)
-    lmfit = utilities.import_lmfit('XU.simpack')
-
-    if plot:
-        plot, plt = utilities.import_matplotlib_pyplot('XU.simpack')
-
-    mask = numpy.logical_and(ai > xmin, ai < xmax)
-    # check Parameters
-    lstack = reflmod.lstack
-    if not isinstance(params, lmfit.Parameters):
-        raise TypeError('params argument must be of type lmfit.Parameters')
-    for lname, l in zip(lstack.namelist, lstack):
-        pname = '{}_thickness'.format(lname)
-        if pname not in params:
-            raise InputError('XU.simpack.fit_xrr: Parameter %s not defined.'
-                             % pname)
-        pname = '{}_roughness'.format(lname)
-        if pname not in params:
-            params.add(pname, value=l.roughness, vary=False)
-            if config.VERBOSITY >= config.INFO_LOW:
-                print("XU.simpack.fit_xrr: adding fixed parameter %s to model"
-                      % pname)
-        pname = '{}_density'.format(lname)
-        if pname not in params:
-            params.add(pname, value=l.density, vary=False)
-            if config.VERBOSITY >= config.INFO_LOW:
-                print("XU.simpack.fit_xrr: adding fixed parameter %s to model"
-                      % pname)
-
-    # residual function
-    def xrr_residual(pars, ai, reflmod, **kwargs):
-        """
-        residual function for lmfit Minimizer routine
-
-        Parameters
-        ----------
-        pars :      lmfit.Parameters
-            fit parameters
-        ai :        array-like
-            array of incidence angles
-        reflmod :   SpecularReflectivityModel
-            reflectivity model object
-        data :      array-like, optional
-            experimental data of same shape as ai (default: None)
-        eps :       array-like
-            experimental error bars of same shape as ai (default: None)
-        """
-        data = kwargs.get('data', None)
-        eps = kwargs.get('eps', None)
-        pvals = pars.valuesdict()
-        # update reflmod global parameters:
-        reflmod.I0 = pvals.get('I0', reflmod.I0)
-        reflmod.background = pvals.get('background', reflmod.background)
-        reflmod.sample_width = pvals.get('sample_width', reflmod.sample_width)
-        reflmod.beam_width = pvals.get('beam_width', reflmod.beam_width)
-        reflmod.resolution_width = pvals.get('resolution_width',
-                                             reflmod.resolution_width)
-        shift = pvals.get('shift', 0)
-        # update layer properties
-        for lname, l in zip(reflmod.lstack.namelist, reflmod.lstack):
-            l.thickness = pvals['{}_thickness'.format(lname)]
-            l.roughness = pvals['{}_roughness'.format(lname)]
-            l.density = pvals['{}_density'.format(lname)]
-        # run simulation
-        model = reflmod.simulate(ai - shift)
-        if data is None:
-            return model
-        if kwargs['elog']:
-            logmodel = numpy.log10(model)
-            logdata = numpy.log10(data)
-            mask = numpy.logical_and(numpy.isfinite(logmodel),
-                                     numpy.isfinite(logdata))
-            return logmodel[mask] - logdata[mask]
-        if eps is None:
-            return (model - data)
-        return (model - data)/eps
-
-    # plot of initial values
-    if plot:
-        plt.ion()
-        if isinstance(plot, str):
-            plt.figure(plot)
-        else:
-            plt.figure('XU:fit_xrr')
-        plt.clf()
-        ax = plt.subplot(111)
-        ax.set_yscale("log", nonposy='clip')
-        if data is not None:
-            if eps is not None:
-                eline = plt.errorbar(ai, data, yerr=eps, ecolor='0.3',
-                                     fmt='ko', errorevery=int(ai.size/80),
-                                     label='data')[0]
-            else:
-                eline, = plt.semilogy(ai, data, 'ko', label='data')
-        if verbose:
-            init, = plt.semilogy(ai,
-                                 xrr_residual(params, ai, reflmod, data=None),
-                                 '-', color='0.5', label='initial')
-        if eline:
-            zord = eline.zorder+2
-        else:
-            zord = 1
-        fline, = plt.semilogy(
-            ai[mask], xrr_residual(params, ai[mask], reflmod, data=None),
-            'r-', lw=2, label='fit', zorder=zord)
-        plt.legend()
-        plt.xlabel('incidence angle (deg)')
-        plt.ylabel('Intensity (arb. u.)')
-        plt.show()
-    else:
-        fline = None
-
-    # create and run minimizer/minimization
-    if eps is None:
-        eps = numpy.ones(ai.shape)
-
-    def cb_func(params, niter, resid, ai, reflmod, **kwargs):
-        if kwargs.get('verbose', False):
-            print('{:04d} {:12.3e}'.format(niter, numpy.sum(resid**2)))
-        if kwargs.get('plot', False) and niter % 20 == 0:
-            fl = kwargs['fline']
-            plt.sca(ax)
-            fl.set_ydata(xrr_residual(params, ai, reflmod, data=None))
-            plt.draw()
-            plt.pause(0.001)  # enable better mpl backend compatibility
-
-    minimizer = lmfit.Minimizer(
-        xrr_residual, params, fcn_args=(ai[mask], reflmod),
-        fcn_kws={'data': data[mask], 'eps': eps[mask], 'fline': fline,
-                 'verbose': verbose, 'plot': plot, 'elog': elog},
-        iter_cb=cb_func, maxfev=maxfev)
-    res = minimizer.minimize()
-
-    # final update of plot
-    if plot:
-        plt.sca(ax)
-        plt.semilogy(ai, xrr_residual(res.params, ai, reflmod, data=None),
-                     'g-', lw=1, label='fit', zorder=fline.zorder-1)
-        cb_func(res.params, 0, res.residual, ai[mask], reflmod, fline=fline,
-                plot=True)
-
-    return res
-
-
 class FitModel(object):
     """
     Wrapper for the lmfit Model class working for instances of LayerModel
@@ -269,12 +72,12 @@ class FitModel(object):
         for p in self.lmodel.fit_paramnames:
             funcstr += "{}, ".format(p)
         # add LayerStack parameters
-        for l in self.lmodel.lstack:
+        for layer in self.lmodel.lstack:
             for param in self.lmodel.lstack_params:
-                funcstr += '{}_{}, '.format(l.name, param)
+                funcstr += '{}_{}, '.format(layer.name, param)
             if self.lmodel.lstack_structural_params:
-                for param in l._structural_params:
-                    funcstr += '{}_{}, '.format(l.name, param)
+                for param in layer._structural_params:
+                    funcstr += '{}_{}, '.format(layer.name, param)
         funcstr += "lmodel=self.lmodel, **kwargs):\n"
         # define modelfunc content
         for p in self.lmodel.fit_paramnames:
@@ -393,10 +196,10 @@ class FitModel(object):
 
                 if weights is not None:
                     eline = self.ax.errorbar(
-                        x, data, yerr=1/weights, ecolor='0.3', fmt='ko',
+                        x, data, yerr=1/weights, ecolor='0.3', fmt='ok',
                         errorevery=int(x.size/80), label='data')[0]
                 else:
-                    eline, = self.ax.plot(x, data, 'ko', label='data')
+                    eline, = self.ax.plot(x, data, 'ok', label='data')
                 if verbose:
                     init, = self.ax.plot(
                         x, model, '-', color='0.5', label='initial')
@@ -427,7 +230,7 @@ class FitModel(object):
                     return
                 if self.fline is None:
                     self.fline, = self.ax.plot(
-                        x, newmodel, 'r-', lw=2, label='fit', zorder=self.zord)
+                        x, newmodel, '-r', lw=2, label='fit', zorder=self.zord)
                 else:
                     self.fline.set_data(x, newmodel)
                 canvas = self.fig.canvas  # see plt.draw function (avoid show!)
@@ -437,7 +240,7 @@ class FitModel(object):
             def addfullmodelline(self, x, y):
                 if not self.plot:
                     return
-                self.ax.plot(x, y, 'g-', lw=1, label='full model',
+                self.ax.plot(x, y, '-g', lw=1, label='full model',
                              zorder=self.zord-1)
 
         if self.mask:
@@ -493,20 +296,20 @@ class FitModel(object):
         self.set_param_hint('energy', min=1000, vary=False)
 
         # parameters of the layerstack
-        for l in self.lmodel.lstack:
+        for lay in self.lmodel.lstack:
             for param in self.lmodel.lstack_params:
-                varname = '{}_{}'.format(l.name, param)
-                self.set_param_hint(varname, value=getattr(l, param), min=0)
+                varname = '{}_{}'.format(lay.name, param)
+                self.set_param_hint(varname, value=getattr(lay, param), min=0)
                 if param == 'density':
-                    self.set_param_hint(varname, max=1.5*l.material.density)
+                    self.set_param_hint(varname, max=1.5*lay.material.density)
                 if param == 'thickness':
-                    self.set_param_hint(varname, max=2*l.thickness)
+                    self.set_param_hint(varname, max=2*lay.thickness)
                 if param == 'roughness':
                     self.set_param_hint(varname, max=50)
             if self.lmodel.lstack_structural_params:
-                for param in l._structural_params:
-                    varname = '{}_{}'.format(l.name, param)
-                    self.set_param_hint(varname, value=getattr(l, param),
+                for param in lay._structural_params:
+                    varname = '{}_{}'.format(lay.name, param)
+                    self.set_param_hint(varname, value=getattr(lay, param),
                                         vary=False)
                     if 'occupation' in param:
                         self.set_param_hint(varname, min=0, max=1)
